###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.0 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder

todoAdd2 = HTMLFile('todoAdd2', globals())
manage_addTodoForm = HTMLFile('todoAdd', globals())


def manage_addTodo(self, id, title, short_body, body, priority, REQUEST=None):
    "Add an instance of the Todo class"

    self._setObject(id, Todo(id, title, short_body, body, priority))

    if REQUEST is not None:

        return self.manage_main(self, REQUEST)


class Todo(
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager
	):
	"Documentation string"

	meta_type = 'Todo'
	icon = 'misc_/TodoFolder/Folder_icon.gif'

	_properties = (
		{'id':'title', 'type':'string'},
		{'id':'short_body', 'type':'string'},
		{'id':'body', 'type':'text'},
		{'id':'priority', 'type':'int'},
		)

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('View Todos',
		 ('',)),
		)

	index_html = HTMLFile('todoIndex', globals())

	priorities = {
		0: 'Low',
		1: 'Medium',
		2: 'High'
		}

	def __init__(self, id, title='', short_body='', body='', priority=''):
		"Initialize the class instance"

		self.id = id
		self.title = title
		self.short_body = short_body
		self.body = body
		self.priority = priority


	def split(self):
		"""Splits up a todo into to separate todos."""

		manage_addTodo(self, self.id + '-1', self.title + '.1',
					   self.short_body, self.body, self.priority)

		manage_addTodo(self, self.id + '-2', self.title + '.2',
					   self.short_body, self.body, self.priority)


	def render_priority(self):
		"""Returns a string indicating the priority."""

		return self.priorities[self.priority]
	

	def display(self):
		"""Returns a view suitable in a larger picture."""

		return """<table border="0">
		<tr><th>(Priority %s)</th><td>%s</td></tr>
		</table>
		""" % (self.render_priority(), self.short_body)


default__class_init__(Todo)

